@@ -13,14 +13,17 @@ def example_classifier(name, eps, eval_eps):
         "GymObject",
         "pendulum",
         sensors=["image", "observation", "reward", "done"],
-        gym_env_id="Pendulum-v0",
-        gym_rate=20,
-        gym_always_render=True,
+        env_id="Pendulum-v0",
+        rate=20,
+        always_render=True,
         render_shape=[28, 28],
     )
 
     # Define PID controller & classifier
-    classifier = Node.make("Classifier", "classifier", rate=20, cam_rate=20, data="../data/with_actions.h5")
+    import os
+
+    dir_path = os.path.dirname(os.path.realpath(__file__))
+    classifier = Node.make("Classifier", "classifier", rate=20, cam_rate=20, data=dir_path + "/../data/with_actions.h5")
     pid = Node.make("PidController", "pid", rate=20, gains=[8, 1, 0], y_range=[-4, 4])
 
     # Define graph (agnostic) & connect nodes
@@ -39,7 +42,7 @@ def example_classifier(name, eps, eval_eps):
     bridge = Bridge.make("GymBridge", rate=20)
 
     # Initialize Environment (agnostic graph +  bridge)
-    env = eagerx_gym.EagerGym(name=name, rate=20, graph=graph, bridge=bridge)
+    env = eagerx_gym.EagerxGym(name=name, rate=20, graph=graph, bridge=bridge)
 
     # Use stable-baselines
     import stable_baselines3 as sb
