@@ -9,7 +9,7 @@ def example_full_state(name, eps, eval_eps):
     initialize("eagerx", anonymous=True, log_level=log.INFO)
 
     # Define object
-    pendulum = Object.make("GymObject", "pendulum", gym_env_id="Pendulum-v0", gym_rate=20)
+    pendulum = Object.make("GymObject", "pendulum", env_id="Pendulum-v0", rate=20)
 
     # Define graph (agnostic) & connect nodes
     graph = Graph.create(objects=[pendulum])
@@ -22,7 +22,7 @@ def example_full_state(name, eps, eval_eps):
     bridge = Bridge.make("GymBridge", rate=20)
 
     # Initialize Environment (agnostic graph +  bridge)
-    env = eagerx_gym.EagerGym(name=name, rate=20, graph=graph, bridge=bridge)
+    env = eagerx_gym.EagerxGym(name=name, rate=20, graph=graph, bridge=bridge)
 
     # Use stable-baselines
     import stable_baselines3 as sb
