@@ -9,7 +9,7 @@ def example_pid_only(name, eps, eval_eps):
     initialize("eagerx", anonymous=True, log_level=log.INFO)
 
     # Define object
-    pendulum = Object.make("GymObject", "pendulum", gym_env_id="Pendulum-v0", gym_rate=20)
+    pendulum = Object.make("GymObject", "pendulum", env_id="Pendulum-v0", rate=20)
 
     # Define PID controller & classifier
     pid = Node.make("PidController", "pid", rate=20, gains=[8, 1, 0], y_range=[-4, 4])
@@ -28,7 +28,7 @@ def example_pid_only(name, eps, eval_eps):
     bridge = Bridge.make("GymBridge", rate=20)
 
     # Initialize Environment (agnostic graph +  bridge)
-    env = eagerx_gym.EagerGym(name=name, rate=20, graph=graph, bridge=bridge)
+    env = eagerx_gym.EagerxGym(name=name, rate=20, graph=graph, bridge=bridge)
 
     # Use stable-baselines
     import stable_baselines3 as sb
